@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -50,7 +50,6 @@ License:
     limitations under the License.
 """
 
-import PyFunceble.factory
 import PyFunceble.storage
 from PyFunceble.checker.availability.extras.base import ExtraRuleHandlerBase
 
@@ -66,6 +65,25 @@ class ParkedRulesHandler(ExtraRuleHandlerBase):
         :class:`~PyFunceble.checker.availability.status.AvailabilityCheckerStatus`
     """
 
+    PARKED_CONTENT_PATTERNS = (
+        'class="parked-domains',
+        "buy-domain",
+        "this domain name is parked",
+        "this domain is parked",
+        "interested in this domain",
+        "really cool domain parked",
+        "domain is for sale",
+        '_trackpageview("/parked/[% parked_type %]/',
+        "| parked domain",
+        "parked banner",
+        "contact with domain owner",
+        "web page is parked",
+        "buy or lease this domain",
+        "parked domain name on ",
+        "it is currently parked by the owner",
+        "parked page for",
+    )
+
     def _switch_down_by_cookie(self) -> "ParkedRulesHandler":
         """
         Tries to switch the status to inactive if some special cookies where found.
@@ -76,31 +94,14 @@ class ParkedRulesHandler(ExtraRuleHandlerBase):
 
         return self
 
-    def _swith_down_by_content(self) -> "ParkedRulesHandler":
+    def _switch_down_by_content(self) -> "ParkedRulesHandler":
         """
         Tries to switch the status to inactive if some relative content were found.
         """
 
         content = self.req.text.lower()
 
-        if (  # pylint: disable=too-many-boolean-expressions
-            'class="parked-domains' in content
-            or "buy-domain" in content
-            or "this domain name is parked" in content
-            or "this domain is parked" in content
-            or "interested in this domain" in content
-            or "really cool domain parked" in content
-            or "domain is for sale" in content
-            or '_trackpageview("/parked/[% parked_type %]/' in content
-            or "| parked domain" in content
-            or "parked banner" in content
-            or "contact with domain owner" in content
-            or "web page is parked" in content
-            or "buy or lease this domain" in content
-            or "parked domain name on " in content
-            or "it is currently parked by the owner" in content
-            or "parked page for" in content
-        ):
+        if any(x in content for x in self.PARKED_CONTENT_PATTERNS):
             self.switch_to_down()
 
         return self
@@ -121,13 +122,13 @@ class ParkedRulesHandler(ExtraRuleHandlerBase):
                 self._switch_down_by_cookie()
 
             if not self.status.status_after_extra_rules:
-                self._swith_down_by_content()
+                self._switch_down_by_content()
 
             PyFunceble.facility.Logger.info(
                 "Finished to check %r against our own set of parked rules.",
                 self.status.idna_subject,
             )
-        except PyFunceble.factory.Requester.exceptions.RequestException:
+        except self.requester.exceptions.RequestException:
             pass
 
         return self
