@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -55,11 +55,9 @@ from typing import Optional
 from box import Box
 
 import PyFunceble.facility
-import PyFunceble.factory
 import PyFunceble.storage
 from PyFunceble.checker.availability.extras.base import ExtraRuleHandlerBase
 from PyFunceble.checker.availability.status import AvailabilityCheckerStatus
-from PyFunceble.helpers.regex import RegexHelper
 
 
 class ExtraRulesHandler(ExtraRuleHandlerBase):
@@ -81,6 +79,7 @@ class ExtraRulesHandler(ExtraRuleHandlerBase):
                 (self.switch_to_down_if_status_code, {410, 424}),
             ],
             r"\.24\.eu$": [(self.switch_to_down_if_status_code, 503)],
+            r"\.3x\.ro$": [(self.switch_to_down_if_status_code, 404)],
             r"\.altervista\.org$": [(self.switch_to_down_if_status_code, 403)],
             r"\.angelfire\.com$": [(self.switch_to_down_if_status_code, 404)],
             r"\.blogspot\.": [self.handle_blogspot],
@@ -90,14 +89,25 @@ class ExtraRulesHandler(ExtraRuleHandlerBase):
             r"\.github\.io$": [(self.switch_to_down_if_status_code, 404)],
             r"\.glitchz\.me$": [(self.switch_to_down_if_status_code, 403)],
             r"\.godaddysites\.com$": [(self.switch_to_down_if_status_code, 404)],
-            r"\.hpg.com.br$": [(self.switch_to_down_if_status_code, 404)],
+            r"\.hpg\.com\.br$": [(self.switch_to_down_if_status_code, 404)],
+            r"^heylink\.me$": [(self.switch_to_down_if_status_code, 410)],
+            r"^heyl\.ink$": [(self.switch_to_down_if_status_code, 410)],
             r"\.imgur\.com$": [self.handle_imgur_dot_com],
             r"\.liveadvert\.com$": [(self.switch_to_down_if_status_code, 404)],
             r"\.myhuaweicloudz\.com$": [(self.switch_to_down_if_status_code, 403)],
+            r"^scnv\.io$": [(self.switch_to_down_if_status_code, 404)],
             r"\.skyrock\.com$": [(self.switch_to_down_if_status_code, 404)],
+            r"\.squarespace.com$": [
+                (self.switch_to_down_if_status_code, 404),
+                self.handle_squarespace_com,
+            ],
             r"\.sz.id$": [(self.switch_to_down_if_status_code, 302)],
             r"\.translate\.goog$": [(self.switch_to_down_if_status_code, 403)],
             r"\.tumblr\.com$": [(self.switch_to_down_if_status_code, 404)],
+            r"\.vercel\.app$": [
+                (self.switch_to_down_if_status_code, 451),
+                self.handle_vercel_dot_app,
+            ],
             r"\.web\.app$": [(self.switch_to_down_if_status_code, 404)],
             r"\.wix\.com$": [(self.switch_to_down_if_status_code, 404)],
             r"^s3\.ap-south-1\.amazonaws\.com$": [
@@ -108,8 +118,8 @@ class ExtraRulesHandler(ExtraRuleHandlerBase):
                 (self.switch_to_down_if_status_code, 410),
                 self.handle_wordpress_dot_com,
             ],
-            r"\.weebly\.com$": [(self.switch_to_down_if_status_code, {"404", "406"})],
-            r"\.zzz\.com\.ua$": [(self.switch_to_down_if_status_code, {"402"})],
+            r"\.weebly\.com$": [(self.switch_to_down_if_status_code, {404, 406})],
+            r"\.zzz\.com\.ua$": [(self.switch_to_down_if_status_code, {402})],
         }
 
         if PyFunceble.facility.ConfigLoader.is_already_loaded():
@@ -124,15 +134,12 @@ class ExtraRulesHandler(ExtraRuleHandlerBase):
         Handles the standard regex lookup case.
         """
 
-        regex_helper = RegexHelper()
-
         for (
             regex,
             data,
         ) in regex_registry.items():
-            broken = False
             for element in data:
-                if not regex_helper.set_regex(regex).match(
+                if not self.regex_helper.set_regex(regex).match(
                     self.status.netloc, return_match=False
                 ):
                     continue
@@ -143,11 +150,7 @@ class ExtraRulesHandler(ExtraRuleHandlerBase):
                     element()
 
                 if self.status.status_after_extra_rules:
-                    broken = True
-                    break
-
-            if broken:
-                break
+                    return self
 
         return self
 
@@ -216,9 +219,7 @@ class ExtraRulesHandler(ExtraRuleHandlerBase):
             This method are assuming we are handling a imgur.com subdomain.
         """
 
-        req = PyFunceble.factory.Requester.get(
-            self.req_url_https, allow_redirects=False
-        )
+        req = self.requester.get(self.req_url_https, allow_redirects=False)
         username = self.status.netloc.replace(".imgur.com", "")
 
         if "Location" in req.headers:
@@ -227,6 +228,56 @@ class ExtraRulesHandler(ExtraRuleHandlerBase):
 
         return self
 
+    def handle_vercel_dot_app(self) -> "ExtraRulesHandler":
+        """
+        Handles the :code:`vercel.app` case.
+
+        .. warning::
+            This method assume that we know that we are handling a vercel.app domain.
+        """
+
+        regex_vercel = [r"This%20Deployment%20has%20been%20disabled"]
+
+        self.do_on_header_match(
+            self.req_url,
+            {"x-vercel-error": ["DEPLOYMENT_DISABLED"]},
+            method=self.switch_to_down,
+            match_mode="std",
+            strict=True,
+            allow_redirects=False,
+        )
+
+        self.do_on_body_match(
+            self.req_url,
+            regex_vercel,
+            method=self.switch_to_down,
+            allow_redirects=False,
+        )
+
+        return self
+
+    def handle_squarespace_com(self) -> "ExtraRulesHandler":
+        """
+        Handles the :code:`wordpress.com` case.
+
+        .. warning::
+            This method assume that we know that we are handling a blogspot domain.
+        """
+
+        regex_squarespace = [
+            r"This&nbsp;site&nbsp;has&nbsp;been&nbsp;deleted"
+            r"&nbsp;by&nbsp;the&nbsp;owner\."
+        ]
+
+        self.do_on_body_match(
+            self.req_url,
+            regex_squarespace,
+            method=self.switch_to_down,
+            allow_redirects=True,
+        )
+
+        return self
+
     def __handle_active2inactive(self) -> "ExtraRulesHandler":
         """
         Handles the status deescalation.
