@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -51,9 +51,10 @@ License:
 """
 
 import PyFunceble.facility
-import PyFunceble.factory
 import PyFunceble.storage
 from PyFunceble.checker.availability.base import AvailabilityCheckerBase
+from PyFunceble.checker.availability.params import AvailabilityCheckerParams
+from PyFunceble.checker.availability.status import AvailabilityCheckerStatus
 from PyFunceble.checker.reputation.ip import IPReputationChecker
 
 
@@ -88,6 +89,22 @@ class IPAvailabilityChecker(AvailabilityCheckerBase):
         WHOIS datasets.
     """
 
+    def subject_propagator(self) -> "IPAvailabilityChecker":
+        """
+        Propagate the currently set subject.
+
+        .. warning::
+            You are not invited to run this method directly.
+        """
+
+        self.status = AvailabilityCheckerStatus()
+        self.params = AvailabilityCheckerParams()
+        self.status.params = self.params
+
+        self.status.subject_kind = "ip"
+
+        return super().subject_propagator()
+
     def try_to_query_status_from_reputation(self) -> "IPAvailabilityChecker":
         """
         Tries to query the status from the reputation lookup.
