@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -55,7 +55,6 @@ from typing import List, Optional
 from sqlalchemy.orm import Session
 
 import PyFunceble.facility
-import PyFunceble.factory
 import PyFunceble.storage
 from PyFunceble.checker.base import CheckerBase
 from PyFunceble.checker.reputation.params import ReputationCheckerParams
@@ -131,8 +130,11 @@ class ReputationCheckerBase(CheckerBase):
         self.ip_syntax_checker.subject = self.idna_subject
         self.url_syntax_checker.subject = self.idna_subject
 
-        self.status = ReputationCheckerStatus()
-        self.status.params = self.params
+        if self.status.subject_kind is None:
+            self.status = ReputationCheckerStatus()
+            self.params = ReputationCheckerParams()
+            self.status.params = self.params
+
         self.status.dns_lookup_record = self.dns_query_tool.lookup_record
 
         return super().subject_propagator()
