@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -53,7 +53,6 @@ License:
 from typing import Optional
 
 from PyFunceble.checker.syntax.domain_base import DomainSyntaxCheckerBase
-from PyFunceble.helpers.regex import RegexHelper
 
 
 class SecondLvlDomainSyntaxChecker(DomainSyntaxCheckerBase):
@@ -108,15 +107,15 @@ class SecondLvlDomainSyntaxChecker(DomainSyntaxCheckerBase):
             if "." in subject_without_suffix:
                 return False
 
-            return RegexHelper(self.REGEX_VALID_DOMAIN).match(
+            return self.regex_helper.set_regex(self.REGEX_VALID_DOMAIN).match(
                 self.idna_subject, return_match=False
-            ) or RegexHelper(self.REGEX_VALID_RELAXED_DOMAIN).match(
+            ) or self.regex_helper.set_regex(self.REGEX_VALID_RELAXED_DOMAIN).match(
                 self.idna_subject, return_match=False
             )
 
         if "." in subject_without_extension:
             return False
 
-        return RegexHelper(self.REGEX_VALID_DOMAIN).match(
+        return self.regex_helper.set_regex(self.REGEX_VALID_DOMAIN).match(
             self.idna_subject, return_match=False
         )
