@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -71,7 +71,7 @@ def producer() -> None:  # pylint: disable=too-many-statements
     description = (
         f"{colorama.Style.BRIGHT}{colorama.Fore.GREEN}PyFunceble Production Preparator"
         f"{colorama.Style.RESET_ALL} - "
-        "The Production peparator for PyFunceble."
+        "The Production preparator for PyFunceble."
     )
 
     parser = argparse.ArgumentParser(
