@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -66,7 +66,6 @@ from PyFunceble.cli.filesystem.dir_structure.restore import (
     DirectoryStructureRestoration,
 )
 from PyFunceble.cli.filesystem.printer.file import FilePrinter
-from PyFunceble.helpers.directory import DirectoryHelper
 from PyFunceble.utils.platform import PlatformUtility
 
 
@@ -78,7 +77,7 @@ class StatusFileGenerator(FilesystemDirBase):
 
     # pylint: disable=too-many-public-methods
 
-    STD_HOSTS_IP: str = "0.0.0.0"
+    STD_HOSTS_IP: str = "0.0.0.0"  # nosec: B104  # Default to non-routable IP
     STD_ALLOW_HOSTS_FILES: bool = True
     STD_ALLOW_PLAIN_FILES: bool = True
     STD_ALLOW_ANALYTIC_FILES: bool = True
@@ -535,7 +534,7 @@ class StatusFileGenerator(FilesystemDirBase):
 
         result = super().get_output_basedir()
 
-        if not DirectoryHelper(result).exists():
+        if not self.directory_helper.set_path(result).exists():
             DirectoryStructureRestoration(self.parent_dirname).start()
         return result
 
@@ -672,7 +671,7 @@ class StatusFileGenerator(FilesystemDirBase):
                 )
 
         if self.test_dataset and "from_inactive" in self.test_dataset:
-            # Let's generate the supicious file :-)
+            # Let's generate the suspicious file :-)
             if self.status.status in [
                 PyFunceble.storage.STATUS.up,
                 PyFunceble.storage.STATUS.valid,
