@@ -36,7 +36,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -92,7 +92,7 @@ class FileAndStatusMigrator(MariaDBMigratorBase):
         )
 
         inactive_dataset = PyFunceble.cli.utils.testing.get_inactive_dataset_object()
-        continue_dataset = PyFunceble.cli.utils.testing.get_continue_databaset_object()
+        continue_dataset = PyFunceble.cli.utils.testing.get_continue_dataset_object()
 
         drop_table = True
 
@@ -106,8 +106,8 @@ class FileAndStatusMigrator(MariaDBMigratorBase):
 
             destination = get_destination_from_origin(file_info["path"])
 
-            for status in self.get_rows(
-                f"SELECT * from pyfunceble_status WHERE file_id = {file_info['id']}"
+            for status in self.get_rows(  # nosec: B608 # Self-Controlled Input
+                "SELECT * from pyfunceble_status WHERE file_id = {file_info['id']}"
             ):
                 if (
                     self.continuous_integration
@@ -144,7 +144,9 @@ class FileAndStatusMigrator(MariaDBMigratorBase):
 
                 # pylint: disable=line-too-long
                 self.db_session.execute(
-                    text(f"DELETE from pyfunceble_status WHERE id = {status['id']}")
+                    text(
+                        f"DELETE from pyfunceble_status WHERE id = {status['id']}"  # nosec: B608 # Self-Controlled Input
+                    )
                 )
                 self.db_session.commit()
 
@@ -155,7 +157,9 @@ class FileAndStatusMigrator(MariaDBMigratorBase):
             if drop_table:
                 # pylint: disable=line-too-long
                 self.db_session.execute(
-                    text(f"DELETE from pyfunceble_file WHERE id = {file_info['id']}")
+                    text(
+                        f"DELETE from pyfunceble_file WHERE id = {file_info['id']}"  # nosec: B608 # Self-Controlled Input
+                    )
                 )
                 self.db_session.commit()
 
