@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -66,4 +66,5 @@ class ChancyProducerProcessesManager(ProcessesManagerBase):
         if you believe in your own luck.
     """
 
-    WORKER_OBJ: ChancyProducerWorker = ChancyProducerWorker
+    STD_NAME: str = "pyfunceble_chancy_producer_worker"
+    WORKER_CLASS: ChancyProducerWorker = ChancyProducerWorker
