@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -55,11 +55,9 @@ from typing import Optional
 import colorama
 from sqlalchemy.orm import Session
 
-import PyFunceble.checker.utils.whois
 import PyFunceble.cli.utils.stdout
 import PyFunceble.cli.utils.testing
 import PyFunceble.facility
-import PyFunceble.factory
 import PyFunceble.storage
 from PyFunceble.cli.continuous_integration.base import ContinuousIntegrationBase
 from PyFunceble.cli.migrators.alembic import Alembic
@@ -90,7 +88,8 @@ class MigratorProcessesManager(ProcessesManagerBase):
     Provides the migrator manager.
     """
 
-    WORKER_OBJ: MigratorWorker = MigratorWorker
+    STD_NAME: str = "pyfunceble_migrator_worker"
+    WORKER_CLASS: MigratorWorker = MigratorWorker
 
     @staticmethod
     def json2csv_inactive_target(
@@ -431,27 +430,37 @@ class MigratorProcessesManager(ProcessesManagerBase):
                 "Stopped csv_file_add_registrar_column_target. File does not exist."
             )
 
-    def create(self) -> "ProcessesManagerBase":
+    def spawn_workers(self, *, start: bool = False) -> "ProcessesManagerBase":
+        """
+        Spawn the necessary workers.
+
+        :param bool start:
+            Whether we should start the workers or not.
+        """
+
         for method in dir(self):
             if not method.endswith("_target"):
                 continue
 
-            worker = MigratorWorker(
-                None,
-                name=f"pyfunceble_{method}",
-                daemon=True,
-                continuous_integration=self.continuous_integration,
-            )
-
+            worker = self.spawn_worker(start=False, daemon=True, force=True)
+            worker.name = f"pyfunceble_{method}"
             worker.target = getattr(self, method)
 
-            self._created_workers.append(worker)
+            if start:
+                worker.start()
+                self.running_workers.append(worker)
+
             PyFunceble.facility.Logger.info("Created worker for %r", method)
 
-    @ProcessesManagerBase.ensure_worker_obj_is_given
-    @ProcessesManagerBase.create_workers_if_missing
+    @ProcessesManagerBase.ensure_worker_class_is_set
+    @ProcessesManagerBase.ensure_worker_spawned
+    @ProcessesManagerBase.ignore_if_running
     def start(self) -> "ProcessesManagerBase":
+        """
+        Starts the migration process.
+        """
+
         # We start the migration (as a standalone)
-        Alembic(self._created_workers[0].db_session).upgrade()
+        Alembic(self.created_workers[0].db_session).upgrade()
 
         return super().start()
