@@ -36,7 +36,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -52,7 +52,7 @@ License:
 """
 # pylint: enable=line-too-long
 
-from typing import Any
+from typing import Any, Optional
 
 from PyFunceble.converter.base import ConverterBase
 
@@ -67,7 +67,7 @@ class Wildcard2Subject(ConverterBase):
     @ConverterBase.data_to_convert.setter
     def data_to_convert(self, value: Any) -> None:
         """
-        Overrites the default behavior.
+        Overrides the default behavior.
 
         :raise TypeError:
             When the given data to convert is not :py:class:`str`
@@ -86,7 +86,7 @@ class Wildcard2Subject(ConverterBase):
 
         return self.convert(self.data_to_convert)
 
-    def convert(self, data: Any, *, aggressive: bool = False) -> str:
+    def convert(self, data: Any, *, aggressive: bool = False) -> Optional[str]:
         """
         Converts the given dataset.
 
