@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -50,7 +50,7 @@ License:
     limitations under the License.
 """
 
-from datetime import datetime
+from datetime import datetime, timezone
 
 from sqlalchemy import Boolean, Column, DateTime, Integer, Text
 
@@ -83,4 +83,6 @@ class Status(SchemaBase):
     url_syntax_validation = Column(Boolean(), default=False, nullable=True)
     is_complement = Column(Boolean(), default=False, nullable=True)
     test_completed = Column(Boolean(), default=False, nullable=False)
-    tested_at = Column(DateTime(), default=datetime.utcnow, nullable=False)
+    tested_at = Column(
+        DateTime(), default=lambda: datetime.now(tz=timezone.utc), nullable=False
+    )
