@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -50,16 +50,17 @@ License:
     limitations under the License.
 """
 
-from datetime import datetime
+from datetime import datetime, timezone
 
 import inflection
 from sqlalchemy import BigInteger, Column, DateTime
-from sqlalchemy.ext.declarative import declarative_base, declared_attr
+from sqlalchemy.ext.declarative import declared_attr
+from sqlalchemy.orm import DeclarativeBase
 
 import PyFunceble.storage
 
 
-class OurSchemaBase:
+class SchemaBase(DeclarativeBase):
     """
     Provides the base of all our schema.
     """
@@ -77,8 +78,14 @@ class OurSchemaBase:
         )
 
     id = Column(BigInteger, primary_key=True, nullable=False)
-    created_at = Column(DateTime(), default=datetime.utcnow, nullable=False)
-    modified_at = Column(DateTime(), default=datetime.utcnow, onupdate=datetime.utcnow)
+    created_at = Column(
+        DateTime(), default=lambda: datetime.now(tz=timezone.utc), nullable=False
+    )
+    modified_at = Column(
+        DateTime(),
+        default=lambda: datetime.now(tz=timezone.utc),
+        onupdate=lambda: datetime.now(tz=timezone.utc),
+    )
 
     def to_dict(self) -> dict:
         """
@@ -86,6 +93,3 @@ class OurSchemaBase:
         """
 
         return {x: y for x, y in self.__dict__.items() if not x.startswith("_sa")}
-
-
-SchemaBase = declarative_base(cls=OurSchemaBase)
