@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -305,9 +305,10 @@ class SQLDBDatasetBase(DBDatasetBase):
             if "expiration_date" not in row and "epoch" not in row:
                 raise exception
 
-            y2k38_limit = datetime(2037, 12, 31, 0, 0)
+            y2k38_limit = datetime(2035, 12, 31, 0, 0, tzinfo=timezone.utc)
             new_date = datetime.fromtimestamp(float(row["epoch"]), timezone.utc)
-            new_date -= new_date - y2k38_limit
+
+            new_date = min(new_date, y2k38_limit)
 
             row["epoch"] = new_date.timestamp()
             row["expiration_date"] = new_date.strftime("%d-%b-%Y")
