@@ -35,7 +35,7 @@ License:
 ::
 
 
-    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024 Nissar Chababy
+    Copyright 2017, 2018, 2019, 2020, 2022, 2023, 2024, 2025 Nissar Chababy
 
     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
@@ -191,7 +191,7 @@ class CommandHelper:
             self.command,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
-            shell=True,
+            shell=True,  # nosec: B602 # Aware of the security implications.
             env=os.environ,
         ) as process:
             stdout, stderr = process.communicate()
@@ -212,7 +212,7 @@ class CommandHelper:
             is that :func:`~PyFunceble.helpers.Command.execute` wait for the
             process to end in order to return its output while this method
             return each line one by one
-            - as they are outputed.
+            - as they are outputted.
 
         :param bool rstrip:
             Deactivates the rstrip of the output.
@@ -222,7 +222,7 @@ class CommandHelper:
             self.command,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT,
-            shell=True,
+            shell=True,  # nosec: B602 # Aware of the security implications.
             env=os.environ,
         ) as process:
             while True:
